==> amphi-etl-0.4.3.tar.gz: amphi-etl-0.4.3/packages/ui-component/src/icons.ts <==
import { LabIcon } from '@jupyterlab/ui-components';

import squareIconSvgStr from '../style/icons/amphi-square-logo.svg';
import amphiLogoSvgStr from '../style/icons/amphi.svg';
import pipelineIconSvgStr from '../style/icons/pipeline-16.svg';
import pipelineNegativeIconSvgStr from '../style/icons/pipeline-16.svg';
import shieldCheckedIconSvgStr from '../style/icons/shield-check-24.svg';
import codeIconSvgStr from '../style/icons/code-16.svg';
import docsIconSvgStr from '../style/icons/docs-16.svg';
import uploadIconSvgStr from '../style/icons/upload-16.svg';
import networkIconSvgStr from '../style/icons/network-24.svg';
import bugIconSvgStr from '../style/icons/bug-16.svg';



export const asteriskIcon = new LabIcon({
  name: 'amphi:asterisk-icon',
  svgstr: squareIconSvgStr
});

export const squareIcon = new LabIcon({
  name: 'amphi:square-icon',
  svgstr: squareIconSvgStr
});

export const amphiLogo = new LabIcon({
  name: 'amphi:logo',
  svgstr: amphiLogoSvgStr
});

export const pipelineIcon = new LabIcon({
  name: 'amphi:pipeline-icon',
  svgstr: pipelineIconSvgStr
});

export const pipelineNegativeIcon = new LabIcon({
  name: 'amphi:pipelinenegative-icon',
  svgstr: pipelineNegativeIconSvgStr
});

export const shieldCheckedIcon = new LabIcon({
  name: 'amphi:shieldchecked-icon',
  svgstr: shieldCheckedIconSvgStr
});

export const codeIcon = new LabIcon({
  name: 'amphi:code-icon',
  svgstr: codeIconSvgStr
});

export const docsIcon = new LabIcon({
  name: 'amphi:docs-icon',
  svgstr: docsIconSvgStr
});

export const uploadIcon = new LabIcon({
  name: 'amphi:upload-icon',
  svgstr: uploadIconSvgStr
});

export const networkIcon = new LabIcon({
  name: 'amphi:network-icon',
  svgstr: networkIconSvgStr
});

export const bugIcon = new LabIcon({
  name: 'amphi:bug-icon',
  svgstr: bugIconSvgStr
});

==> amphi-etl-0.9.0a3.tar.gz: amphi-etl-0.9.0a3/packages/ui-component/src/icons.ts <==
import { LabIcon } from '@jupyterlab/ui-components';

import squareIconSvgStr from '../style/icons/amphi-square-logo.svg';
import amphiLogoSvgStr from '../style/icons/amphi.svg';
import pipelineIconSvgStr from '../style/icons/pipeline-16.svg';
import pipelineNegativeIconSvgStr from '../style/icons/pipeline-16.svg';
import shieldCheckedIconSvgStr from '../style/icons/shield-check-24.svg';
import codeIconSvgStr from '../style/icons/code-16.svg';
import docsIconSvgStr from '../style/icons/docs-16.svg';
import uploadIconSvgStr from '../style/icons/upload-16.svg';
import networkIconSvgStr from '../style/icons/network-24.svg';
import bugIconSvgStr from '../style/icons/bug-16.svg';

import githubIconSvgStr from '../style/icons/github.svg';
import discourseIconSvgStr from '../style/icons/discourse.svg';
import alertCircleFillSvgStr from '../style/icons/alert-circle-fill-24.svg';
import alertDiamondSvgStr from '../style/icons/alert-diamond-24.svg';

export const alertDiamondIcon = new LabIcon({
  name: 'amphi:alertDiamond-icon',
  svgstr: alertDiamondSvgStr
});

export const alertCircleFillIcon = new LabIcon({
  name: 'amphi:alertCircleFill-icon',
  svgstr: alertCircleFillSvgStr
});

export const asteriskIcon = new LabIcon({
  name: 'amphi:asterisk-icon',
  svgstr: squareIconSvgStr
});

export const squareIcon = new LabIcon({
  name: 'amphi:square-icon',
  svgstr: squareIconSvgStr
});

export const amphiLogo = new LabIcon({
  name: 'amphi:logo',
  svgstr: amphiLogoSvgStr
});

export const pipelineIcon = new LabIcon({
  name: 'amphi:pipeline-icon',
  svgstr: pipelineIconSvgStr
});

export const pipelineNegativeIcon = new LabIcon({
  name: 'amphi:pipelinenegative-icon',
  svgstr: pipelineNegativeIconSvgStr
});

export const shieldCheckedIcon = new LabIcon({
  name: 'amphi:shieldchecked-icon',
  svgstr: shieldCheckedIconSvgStr
});

export const codeIcon = new LabIcon({
  name: 'amphi:code-icon',
  svgstr: codeIconSvgStr
});

export const docsIcon = new LabIcon({
  name: 'amphi:docs-icon',
  svgstr: docsIconSvgStr
});

export const uploadIcon = new LabIcon({
  name: 'amphi:upload-icon',
  svgstr: uploadIconSvgStr
});

export const networkIcon = new LabIcon({
  name: 'amphi:network-icon',
  svgstr: networkIconSvgStr
});

export const bugIcon = new LabIcon({
  name: 'amphi:bug-icon',
  svgstr: bugIconSvgStr
});

export const githubIcon = new LabIcon({
  name: 'amphi:github-icon',
  svgstr: githubIconSvgStr
});

export const discourseIcon = new LabIcon({
  name: 'amphi:discourse-icon',
  svgstr: discourseIconSvgStr
});
